Changelog
=========


1.0.0a5 (2021-12-19)
--------------------

- Remove the use of accordion in edit forms [sverbois]
- Remove the row prototype. We want a KISS product [sverbois]


1.0.0a4 (2021-12-19)
--------------------

- Add tags information in section view which contains context subjects field value [sverbois]
- Clean up the list of behaviours on content types [sverbois]
- Don't hide *contentleadimage* viewlet [sverbois]

1.0.0a3 (2021-12-18)
--------------------

- Add a demo.json export of collective.exportimport with demo pages [sverbois]
- Clean use of default and missing_value field attributes [sverbois]


1.0.0a2 (2021-12-17)
--------------------

- Add Event Page portal type [sverbois]


1.0.0a1 (2021-12-17)
--------------------

- Initial release [sverbois]
